#! /usr/bin/env python
# coding: utf-8

import os
import sys
import re
from mysqldb_rich.db2 import TableDB, DB
from jingyun_cli import logger
from jingyun_cli.util.cli_args import args_man
from jingyun_cli.util.help import error_and_exit
from jingyun_cli.util.env import get_environ
try:
    from .help import g_help
except ValueError:
    from help import g_help

__author__ = '鹛桑够'


def check_file_exist(file_path):
    if os.path.exists(file_path) is False:
        error_and_exit(g_help("file_lost", file_path))


def create_table(args):
    if args.conf_path is None:
        args.conf_path = get_environ("DB_CONF_PATH")
    t = TableDB(conf_path=args.conf_path)
    suffix_comp = re.compile(r"\w+\.(json|function|procedure|trigger|view)$", re.I)
    all_files = args.files
    if args.file_prefix is not None:
        all_files = map(lambda x: args.file_prefix + x, all_files)
    if args.directory is not None:
        desc_files = os.listdir(args.directory)
        all_files.extend(map(lambda x: os.path.join(args.directory, x), desc_files))
    for file_path in all_files:
        filename = os.path.split(file_path)[1]
        if suffix_comp.match(filename) is None:
            logger.warning(g_help("skip_file", file_path))
            continue
        logger.info(g_help("handle_file", file_path))
        check_file_exist(file_path)
        if file_path.endswith(".json"):
            r = t.create_from_json_file(file_path)
        else:
            with open(file_path) as rf:
                c = rf.read()
                ds = re.findall(r"(DROP[\s\S]+? IF EXISTS[\s\S]+?(;|\n))", c, re.I)
                for item in ds:
                    t.execute(item[0])
                fs = re.findall(r"(CREATE[\s\S]+?(END;|END\n|$))", c)
                for item in fs:
                    t.execute(item[0])


def op_table():
    commands_man = args_man.add_subparsers(title="Commands", description=None, metavar="COMMAND OPTIONS", dest="sub_cmd")
    create_man = commands_man.add_parser("create", help=g_help("create"))
    create_man.add_argument("-c", metavar="path", dest="conf_path", help=g_help("conf_path"))
    create_man.add_argument("-d", metavar="path", dest="directory", help=g_help("dir"))
    create_man.add_argument("--file-prefix", metavar="path", dest="file_prefix", help=g_help("file_prefix"))
    create_man.add_argument("-f", metavar="path", dest="files", help=g_help("file"), nargs="*", default=[])

    if len(sys.argv) <= 1:
        sys.argv.append("-h")
    args = args_man.parse_args()
    if args.sub_cmd == "create":
        create_table(args)


def link():
    args_man.add_argument("-c", metavar="path", dest="conf_path", help=g_help("conf_path"))
    args_man.add_argument("-r", "--readonly", dest="readonly", action="store_true", help=g_help("readonly"),
                          default=False)
    args = args_man.parse_args()
    if args.conf_path is None:
        args.conf_path = get_environ("DB_CONF_PATH")
    t = DB(conf_path=args.conf_path, readonly=args.readonly)
    t.link()

if __name__ == "__main__":
    # sys.argv.extend(["create", "-h"])
    # sys.argv.extend(["create", "-c", "/mnt/dataJINGD/conf/mysql_app.conf", "-d", "../../../GATCAPI/Table/Function/", "--file-prefix", "../../../GATCAPI/Table/Trigger/", "-f", "t_update_stage.trigger", "t_update_stage.trigger"])
    sys.argv.extend(["-c", "/mnt/data/JINGD/conf/mysql_app.conf"])
    link()



#! /usr/bin/env python
# coding: utf-8

import os
import sys
import yaml
from compose.cli.main import main as compose_main
from jingyun_cli import logger
from jingyun_cli.util.cli_args import args_man, parse_args
try:
    from .help import g_help, error_and_exit
except ValueError:
    from help import g_help, error_and_exit


__author__ = '鹛桑够'


def get_file(compose_dir):
    if compose_dir is None:
        compose_dir = os.environ.get("JINGD_CONF_DIR", ".")
    file_path = os.path.join(compose_dir, "docker-compose.yml")
    return file_path


def write_conf(args):
    if len(sys.argv) <= 1:
        sys.argv.append("-h")
    service_name = args.name
    service_item = dict(image=args.image)
    if args.volumes is not None:
        service_item["volumes"] = args.volumes
    if args.ports is not None:
        service_item["ports"] = args.ports
        for port in args.ports:
            port_p = port.split(":")
            if port_p[0] != port_p[1]:
                break
        else:
            service_item["network_mode"] = "host"
            del service_item["ports"]

    if args.restart is not None:
        service_item["restart"] = args.restart
    if args.command is not None:
        service_item["command"] = " ".join(args.command)
    if args.environments is not None:
        service_item["environment"] = args.environments
    if args.working_dir is not None:
        service_item["working_dir"] = args.working_dir
    file_path = get_file(args.compose_dir)
    if os.path.exists(file_path) is False:
        logger.debug(g_help("create", file_path))
        o_y = dict(version='2', services={service_name: service_item})
    else:
        f = open(file_path)
        o_y = yaml.load(f)
        if service_name in o_y["services"]:
            logger.debug(g_help("exist_service"))
        o_y["services"][service_name] = service_item
    w_f = open(file_path, "w")
    yaml.dump(o_y, stream=w_f, default_flow_style=False)


def main():
    commands_man = args_man.add_subparsers(title="Commands", description=None, metavar="COMMAND", dest="sub_cmd")

    config_man = commands_man.add_parser("config", help=g_help("action_config"))
    config_man.add_argument("command", nargs="*", help=g_help("command"))
    config_man.add_argument("-d", dest="compose_dir", help=g_help("compose_dir"))
    config_man.add_argument("-e", "--environment", dest="environments", help=g_help("env"), action="append")
    config_man.add_argument("-f", "--file", dest="file_path", help=g_help("file"))
    config_man.add_argument("-n", "--name", dest="name", help=g_help("name"), required=True)
    config_man.add_argument("-i", "--image", dest="image", help=g_help("image"), required=True)
    config_man.add_argument("-v", "--volumes", dest="volumes", help=g_help("volumes"), action="append")
    config_man.add_argument("-p", "--ports", help=g_help("ports"), action="append")
    config_man.add_argument("--restart", help=g_help("restart"))
    config_man.add_argument("-w", "--working-dir", dest="working_dir", help=g_help("working_dir"))

    # commands_man.add_parser("kill", help="")

    # up_man = commands_man.add_parser("up", help="execute docker-compose up")
    # up_man.add_argument("args", nargs="*")
    if len(sys.argv) <= 1:
        sys.argv.append("-h")
    args = parse_args()
    if args.sub_cmd == "config":
        write_conf(args)
    else:
        file_path = get_file(None)
        sys.argv.insert(1, "-f")
        sys.argv.insert(2, file_path)
        compose_main()


if __name__ == "__main__":
    sys.argv.extend(["--debug", "config", "-n", "qc", "-i", "meisanggou/qc", "-v", "${JINGD_DATA_ROOT}:${JINGD_DATA_ROOT}",
                     "-v", "${JINGD_CONF_DIR}:${JINGD_CONF_DIR}", "-p", "6379:6379", "-v", "${GATCAPI_DIR}/Worker:/opt/worker",
                     "-w", "/opt/worker", "python", "SampleSequencingLocalWorker.py"])
    main()



#! /usr/bin/env python
# coding: utf-8

import socket

__author__ = '鹛桑够'


def is_listen(port, host="127.0.0.1"):
    sock = socket.socket()
    address = (host, port)
    result = sock.connect_ex(address)
    if result == 0:
        return True
    else:
        return False



#! /usr/bin/env python
# coding: utf-8

import sys
import logging

__author__ = '鹛桑够'


logger = logging.getLogger("jy_cli")
if len(logger.handlers) <= 0:
    sh = logging.StreamHandler(sys.stdout)
    logger.addHandler(sh)
    logger.setLevel(logging.INFO)


#! /usr/bin/env python
# coding: utf-8

from jingyun_cli import logger
from jingyun_cli.util.host import get_default_ip
from jingyun_cli.util.cli_args import args_man
from help import g_help

__author__ = '鹛桑够'


def get_ip():

    default_ip = get_default_ip()
    logger.info(default_ip)

if __name__ == "__main__":
    get_ip()



#! /usr/bin/env python
# coding: utf-8

import sys
from functools import partial
from jingyun_cli.util.help import help_value, error_and_exit

__author__ = '鹛桑够'

conf_path_help = {"en": "", "cn": "配置文件所在的路径，默认会读取DB_CONF_PATH这个环境变量"}
dir_help = {"en": "", "cn": "会读取该目录下相应的文件。表结构.json，存储过程.procedure，视图.view，触发器.trigger，函数.function"}
file_help = {"en": "", "cn": "结构描述文件，文件后缀必须满足表结构.json，存储过程.procedure，视图.view，触发器.trigger，函数.function结尾"}
file_prefix_help = {"en": "", "cn": "文件路径前缀，和参数-f一起使用。该参数设置后，-f跟的文件路径全部前面加上该参数后使用"}
create_help = {"en": "", "cn": "根据描述，批量新建表或者存储过程，视图，或者触发器，函数"}
handle_file_help = {"en": "", "cn": "正在处理文件%s"}
skip_file_help = {"en": "", "cn": "跳过文件%s，后缀名不符合要求或者文件名中包含\w以外的字符"}
readonly_help = {"en": "", "cn": "使用只读账户"}

help_keys = filter(lambda x: x.endswith("_help"), locals().keys())
help_dict = dict()
for key in help_keys:
    help_dict[key[:-5]] = locals()[key]


g_help = partial(help_value, help_dict)




#! /usr/bin/env python
# coding: utf-8

import os
import sys
import requests
from jingyun_cli import logger
from jingyun_cli.util.cli_args import args_man
from jingyun_cli.util.env import get_environ
try:
    from .help import g_help, error_and_exit
except ValueError:
    from help import g_help, error_and_exit

__author__ = '鹛桑够'


default_endpoint = "http://jy-softs.oss-cn-beijing.aliyuncs.com"


def head_url(url):
    resp = requests.head(url)
    return resp.status_code


def add_output():
    args_man.add_argument("-o", "--output", dest="output", help=g_help("output"), metavar="output")


def get_download_url(endpoint, oss_file, *oss_dir):
    endpoint = endpoint.rstrip("/")
    oss_dirs = map(lambda x: x.strip("/"), oss_dir)
    oss_dirs = filter(lambda x: x != "", oss_dirs)
    dir_path = "/".join(oss_dirs)
    if len(dir_path) > 0:
        url = "%s/%s/%s" % (endpoint, dir_path, oss_file)
    else:
        url = "%s/%s" % (endpoint, oss_file)
    return url


def download_action(endpoint, oss_dir, oss_item, save_path, force=False, custom_dir=""):
    if os.path.exists(save_path) is True and force is False:
        logger.warning(g_help("exist", oss_item))
        return 0
    logger.info(g_help("download", oss_item, save_path))
    custom_url = ""
    if custom_dir != "":
        custom_url = get_download_url(endpoint, oss_item, oss_dir, custom_dir)
        code = head_url(custom_url)
        if code != 200:
            logger.debug(g_help("head_error", custom_url, code))
            custom_url = ""
    if custom_url == "":
        url = get_download_url(endpoint, oss_item, oss_dir)
        code = head_url(url)
        if code != 200:
            error_and_exit(g_help("head_error", url, code))
    else:
        url = custom_url
    cmd = ["curl", "-o", save_path, url]
    e_code = os.system(" ".join(cmd))
    return e_code


def multi_download():
    args_man.add_argument("--allow-custom", dest="allow_custom", help=g_help("allow_custom"), action="store_true", default=False)
    args_man.add_argument("-d", "--oss-dir", dest="oss_dir", help=g_help("oss_dir"), metavar="", default="")
    args_man.add_argument("-e", "--endpoint", dest="endpoint", help=g_help("endpoint"), metavar="",
                         default=default_endpoint)
    args_man.add_argument("-n", "--name", dest="name", metavar="filename", help=g_help("name"))
    args_man.add_argument("-f", "--force", action="store_true", help=g_help("force"), default=False)
    args_man.add_argument("files", metavar="oss_file", nargs="*", help=g_help("oss_file"))
    add_output()
    if len(sys.argv) <= 1:
        sys.argv.append("-h")
    args = args_man.parse_args()
    allow_custom = args.allow_custom
    if allow_custom is True:
        jingd_env = get_environ("JINGD_ENV", "")
        if jingd_env == "":
            logger.warning(g_help("empty_env"))
    else:
        jingd_env = ""
    f_inputs = args.files
    out_dir = args.output
    if out_dir is None:
        out_dir = "."
    if len(f_inputs) == 1:
        name = args.name if args.name is not None else f_inputs[0]
        save_path = os.path.join(out_dir, name)
        e_code = download_action(args.endpoint, args.oss_dir, f_inputs[0], save_path, force=args.force)
        if e_code != 0:
            error_and_exit(g_help("error", f_inputs[0]))
    else:
        for item in f_inputs:
            save_path = os.path.join(out_dir, item)
            e_code = download_action(args.endpoint, args.oss_dir, item, save_path, force=args.force, custom_dir=jingd_env)
            if e_code != 0:
                error_and_exit(g_help("error", item))

if __name__ == "__main__":
    sys.argv.extend(["-d", "shell", "nonkey.sh", "deploy_api.sh", "-n", "a.sh", "-f", "--allow-custom", "--debug"])
    multi_download()



#! /usr/bin/env python
# coding: utf-8

import sys
from functools import partial
from jingyun_cli import logger
from jingyun_cli.util.help import help_value, error_and_exit, jy_input

__author__ = '鹛桑够'

user_help = {"en": "", "cn": "晶读平台账户名"}
new_password_help = {"en": "", "cn": "要设置的密码，默认为123456"}
action_help = {"en": "", "cn": "reset重置晶读平台密码；lock锁定账户；unlock解除锁定账户；genetic授予访问晶读的权限"}
defect_env_help = {"en": "", "cn": "缺少环境变量%s"}
sample_no_help = {"en": "", "cn": "样本编号必须时数字"}

help_keys = filter(lambda x: x.endswith("_help"), locals().keys())
help_dict = dict()
for key in help_keys:
    help_dict[key[:-5]] = locals()[key]

g_help = partial(help_value, help_dict)




#! /usr/bin/env python
# coding: utf-8

import sys
from functools import partial
from jingyun_cli.util.help import help_value, error_and_exit

__author__ = '鹛桑够'


output_help = {"en": "the output of file, default is work dir.", "cn": "下载后的文件保存的目录，默认保存到当前工作目录"}
oss_file_help = {"en": "the name of oss file", "cn": "oss 文件的文件名"}
oss_dir_help = {"en": "the oss directory of the oss file", "cn": "要下载的oss文件所在的oss目录"}
endpoint_help = {"en": "oss server endpoint, for example http://jy-softs.oss-cn-beijing.aliyuncs.com",
                 "cn": "服务器端点,例如http://jy-softs.oss-cn-beijing.aliyuncs.com"}

name_help = {"en": "", "cn": "下载后保存的文件名，仅在下载文件只有一个时有效，超过一个下载文件将忽略该参数"}
exist_help = {"en": "", "cn": "文件%s已存在将不执行下载操作"}
error_help = {"en": "", "cn": "下载文件%s未执行成功"}
download_help = {"en": "", "cn": "下载文件 %s 到 %s"}
force_help = {"en": "", "cn": "无论要下载的文件是否已存在，都进行下载"}
allow_custom_help = {"en": "", "cn": "是否允许定制，允许定制时，优先下载传入目录，环境变量JINGD_ENV子目录的文件"}
empty_env_help = {"en": "", "cn": "设置了allow_custom，但是却没有环境变量JINGD_ENV"}
head_error_help = {"en": "", "cn": "未获得链接%s信息，返回状态为%s"}

help_keys = filter(lambda x: x.endswith("_help"), locals().keys())
help_dict = dict()
for key in help_keys:
    help_dict[key[:-5]] = locals()[key]


g_help = partial(help_value, help_dict)



#! /usr/bin/env python
# coding: utf-8

import os
import requests
try:
    from .help import g_help, error_and_exit
except ValueError:
    from help import g_help, error_and_exit

__author__ = '鹛桑够'


user_agent = "Mozilla/5.0 (Windows NT 10.0; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/63.0.3239.132 Safari/537.36"


def request_jingd(service, method, url, data):
    endpoint_env = "JINGD_%s_ENDPOINT" % service.upper()
    auth_endpoint = os.environ.get(endpoint_env)
    if auth_endpoint is None:
        error_and_exit(g_help("defect_env", endpoint_env), -1)
    headers = {"Content-Type": "application/json", "User-Agent": user_agent}
    url = "%s%s" % (auth_endpoint, url)
    if method == "GET":
        resp = requests.request(method, url, headers=headers, params=data)
    else:
        resp = requests.request(method, url, headers=headers, json=data)
    if resp.status_code != 200:
        error_and_exit("%s %s" % (url, resp.status_code))
    r_data = resp.json()
    if r_data["status"] % 10000 < 100:
        print(r_data["message"])
    else:
        error_and_exit(r_data["message"])
    return r_data



#! /usr/bin/env python
# coding: utf-8

import sys
from functools import partial
from jingyun_cli.util.help import help_value, error_and_exit

__author__ = '鹛桑够'

action_config_help = {"en": "", "cn": "更新或新建一个compose服务配置"}
name_help = {"en": "", "cn": "服务的名称"}
file_help = {"en": "", "cn": "compose文件路径"}
compose_dir_help = {"en": "", "cn": "docker-compose.yml所在目录，默认读取环境变量JINGD_CONF_DIR"}
image_help = {"en": "", "cn": "镜像名称"}
ports_help = {"en": "", "cn": "要映射的端口号，例如80:80，可设置多次"}
volumes_help = {"en": "", "cn": "要映射的目录，例如/host/data:/vm/data，可以设置多次"}
restart_help = {"en": "", "cn": "容器的重启策略，可以设置为always"}
create_help = {"en": "", "cn": "文件%s不存在，将会创建"}
exist_service_help = {"en": "", "cn": "compose服务已经存在，将会更新"}
command_help = {"en": "", "cn": "启动容器时执行的命令"}
env_help = {"env": "", "cn": "启动容器时设置的环境变量"}
working_dir_help = {"env": "", "cn": "容器启动时的工作目录"}

help_keys = filter(lambda x: x.endswith("_help"), locals().keys())
help_dict = dict()
for key in help_keys:
    help_dict[key[:-5]] = locals()[key]


g_help = partial(help_value, help_dict)




#! /usr/bin/env python
# coding: utf-8

import sys
import six

__author__ = '鹛桑够'


lang = "cn"
encoding = "utf-8"
second_encoding = "gb18030"


def decode(s):
    if isinstance(s, six.binary_type):
        try:
            return s.decode(encoding)
        except UnicodeError:
            return s.decode(second_encoding, "replace")
    if isinstance(s, (int, six.integer_types)):
        return "%s" % s
    return s


def encode(s):
    if isinstance(s, six.text_type):
        return s.encode(encoding)
    return s


def is_string(s):
    if isinstance(s, (six.binary_type, six.text_type)) is False:
        return False
    return True


def error_and_exit(msg, error_code=1):
    sys.stderr.write(encode(msg))
    sys.stderr.write("\n")
    sys.exit(error_code)

default_help_dict = dict(
    file_lost=dict(
        en="file [%s] not exist or can not readable",
        cn="文件[%s]不存在或者无权限读取"
    ),
    dir_lost=dict(
        en="directory [%s] not exist or can not readable",
        cn="目录[%s]不存在或者无权限读取"
    ),
    env_lost=dict(
        en="",
        cn=""
    ),
    debug=dict(
        en=" Enter the debug mode,  print out as much information as possible.",
        cn="进入debug模式尽可能多的打印出信息"
    )
)


def help_value(help_dict, key, *args):
    if key in help_dict:
        msg = help_dict[key][lang]
    elif key in default_help_dict:
        msg = default_help_dict[key][lang]
    else:
        raise KeyError("Not find help for %s" % key)
    msg = decode(msg)
    if len(args) > 0:
        args = map(decode, args)
        msg = msg % tuple(args)
    return msg


def jy_input(prompt, prompt_prefix=None):
    if prompt_prefix is not None and prompt is not None:
        prompt = "".join([prompt_prefix, prompt])
    if not prompt.endswith("\n"):
        prompt += "\n"
    if sys.version_info[0] == 2:
        return raw_input(prompt)
    else:
        return input(prompt)


#! /usr/bin/env python
# coding: utf-8

import os

__author__ = '鹛桑够'


def clear():
    c_ps = "docker rm `docker ps -a -q`"
    os.system(c_ps)

    c_volume = "docker volume rm $(docker volume ls -qf dangling=true)"
    os.system(c_volume)

    c_image = "docker image rmi $(docker images -qf dangling=true)"
    os.system(c_image)

if __name__ == "__main__":
    clear()



#! /usr/bin/env python
# coding: utf-8

import sys
import os
import requests
import argparse
try:
    from .help import g_help, error_and_exit
except ValueError:
    from help import g_help, error_and_exit

user_agent = "Mozilla/5.0 (Windows NT 10.0; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/63.0.3239.132 Safari/537.36"


def request_auth(method, url, data):
    auth_endpoint = os.environ.get("JINGD_AUTH_ENDPOINT")
    if auth_endpoint is None:
        error_and_exit(g_help("defect_env", "JINGD_AUTH_ENDPOINT"), -1)
    headers = {"Content-Type": "application/json", "User-Agent": user_agent}
    url = "%s%s" % (auth_endpoint, url)
    resp = requests.request(method, url, headers=headers, json=data)
    if resp.status_code != 200:
        error_and_exit(resp.status_code)
    r_data = resp.json()
    if r_data["status"] % 10000 < 100:
        print(r_data["message"])
    else:
        error_and_exit(r_data["message"])


def request_api(method, url, data):
    api_endpoint = os.environ.get("JINGD_API_ENDPOINT")
    if api_endpoint is None:
        error_and_exit(g_help("defect_env", "JINGD_API_ENDPOINT"), -1)
    headers = {"Content-Type": "application/json", "User-Agent": user_agent}
    url = "%s%s" % (api_endpoint, url)
    resp = requests.request(method, url, headers=headers, json=data)
    if resp.status_code != 200:
        error_and_exit(resp.status_code)
    r_data = resp.json()
    if r_data["status"] % 10000 < 100:
        print(r_data["message"])
    else:
        error_and_exit(r_data["message"])


def new_user(account, password):
    url = "/auth/"
    method = "POST"
    data = {"account": account, "password": password}
    request_auth(method, url, data)


def reset_password(account, password):
    url = "/auth/password/reset/admin/"
    method = "PUT"
    data = {"account": account, "new_password": password}
    request_auth(method, url, data)


def block_user(account):
    url = "/auth/account/block/admin/"
    method = "PUT"
    data = {"account": account}
    request_auth(method, url, data)


def unlock_user(account):
    url = "/auth/account/unlock/admin/"
    method = "PUT"
    data = {"account": account}
    request_auth(method, url, data)


def grant_genetic(account):
    url = "/api/v2/auth/grant/genetic/"
    method = "POST"
    data = {"account": account, "auth_code": "JINGDu"}
    request_api(method, url, data)


def cli_main():
    parser = argparse.ArgumentParser()
    parser.add_argument("-a", "--action", dest="action", help=g_help("action"), choices=["reset", "block", "unlock",
                                                                                         "genetic", "new"])
    parser.add_argument("-u", "--user", dest="user", help=g_help("user"))
    parser.add_argument("-p", "--password", dest="password", help=g_help("new_password"), default="123456")
    if len(sys.argv) <= 1:
        sys.argv.append("-h")

    args = parser.parse_args()

    if args.action is None:
        error_and_exit("Please Set [action] use -a or --action", 1)
    if args.user is None:
        error_and_exit("Please Set [user] use -u or --user", 2)
    if args.action == "reset":
        reset_password(args.user, args.password)
    elif args.action == "block":
        block_user(args.user)
    elif args.action == "unlock":
        unlock_user(args.user)
    elif args.action == "genetic":
        grant_genetic(args.user)
    elif args.action == "new":
        new_user(args.user, args.password)


if __name__ == "__main__":
    sys.argv.extend(["-a", "genetic", "-u", "zh_test"])
    cli_main()



#! /usr/bin/env python
# coding: utf-8

import logging
import argparse
from jingyun_cli import logger
from help import help_value

__author__ = '鹛桑够'


class ArgumentParser(argparse.ArgumentParser):

    def parse_args(self, args=None, namespace=None):
        self.add_argument("--verbose", "--debug", dest="debug", action="store_true", default=False,
                          help=help_value({}, "debug"))
        args_r = argparse.ArgumentParser.parse_args(self, args, namespace)
        if args_r.debug is True:
            logger.setLevel(logging.DEBUG)
        return args_r


args_man = ArgumentParser()


def parse_args(args=None, namespace=None):
    args_r = args_man.parse_args(args, namespace)
    if args_r.debug is True:
        logger.setLevel(logging.DEBUG)
    return args_r



#! /usr/bin/env python
# coding: utf-8

import socket

__author__ = '鹛桑够'


def get_default_ip():
    s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
    s.connect(("114.114.114.114", 53))
    return s.getsockname()[0]


if __name__ == "__main__":
    ip = get_default_ip()
    print(ip)


#! /usr/bin/env python
# coding: utf-8

import sys
import re
from jingyun_cli import logger
from jingyun_cli.util.port import is_listen
from jingyun_cli.util.cli_args import args_man
from help import g_help

__author__ = '鹛桑够'


redis = [6379, 9532, 9531, 9530, 9529, 9528, 9527, 9526, 9525, 9524,
         6379, 8532, 8531, 8530]
mysql = [3306, 9536, 9537, 9538, 9539, 9540, 9541, 9542, 9543, 9544,
         3306, 8536, 8537, 8538]
nginx = [80, 9580, 9579, 9579, 9578]
registry = [5000, 5001, 5002, 5003, 5004, 5005, 5006, 5007, 5008, 5009,
            5010]

define_server = dict(nginx=nginx, mysql=mysql, redis=redis, registry=registry)


def find_one_port():
    args_man.add_argument("-s", "--server", dest="server", help=g_help("server"), choices=define_server.keys())
    args_man.add_argument("-p", "--ports", dest="ports", help=g_help("port"), nargs="*")

    args = args_man.parse_args()
    all_ports = []
    if args.server is not None:
        all_ports.extend(define_server[args.server])
    if args.ports is not None:
        for port in args.ports:
            ports = re.split(r"\D", port)
            ports = map(lambda x: int(x), filter(lambda x: len(x) > 0, ports))
            all_ports.extend(ports)
    for item in all_ports:
        logger.debug("check is listen %s" % item)
        if is_listen(item) is False:
            logger.info(item)
            sys.exit(0)
    sys.exit(1)

if __name__ == "__main__":
    sys.argv.extend(["-p", "9532", "80,2201,,2200"])
    find_one_port()


#! /usr/bin/env python
# coding: utf-8

import os
import sys
import requests
import argparse
try:
    from .help import g_help, error_and_exit
except ValueError:
    from help import g_help, error_and_exit

__author__ = '鹛桑够'


default_endpoint = "https://dms.gene.ac/dist/key/"
headers = {"User-Agent": "jyrequests"}
arg_man = argparse.ArgumentParser()


def add_output():
    arg_man.add_argument("-o", "--output", dest="output", help=g_help("output"), metavar="output")


def get_key(endpoint, app, filters):
    params = dict(app=app)
    for item in filters:
        s = item.split("=", 1)
        if len(s) != 2:
            error_and_exit(g_help("error_filter", item))
        params[s[0]] = s[1]
    try:
        resp = requests.get(endpoint, params=params, headers=headers)
        if resp.status_code != 200:
            error_and_exit(g_help("error_get", resp.status_code))
        r_data = resp.json()
        if r_data["status"] is False:
            error_and_exit(r_data["data"])
        data = r_data["data"]
        for key in data.keys():
            if key[0] == "_":
                data[key[1:]] = data[key]
                del data[key]
    except requests.RequestException as re:
        error_and_exit(g_help("error_get", str(re)))
        return
    except ValueError as ve:
        error_and_exit(g_help("error_get", str(ve)))
        return
    except KeyError as ke:
        error_and_exit(g_help("error_get", str(ke)))
        return
    return data


def replace_file(file_path, value_dict):
    if file_path is None:
        return
    if os.path.exists(file_path) is False:
        msg = g_help("file_not_exist", file_path)
        error_and_exit(msg)
    try:
        with open(file_path) as rf:
            c = rf.read()
    except IOError:
        error_and_exit(g_help("read_error", file_path))
        return
    c2 = c % value_dict
    try:
        with open(file_path, "w") as wf:
            wf.write(c2)
    except IOError:
        error_and_exit(g_help("write_error", file_path))
        return


def handle_key():
    arg_man.add_argument("-a", "--app", dest="app", help=g_help("app"), metavar="app_name", default="")
    arg_man.add_argument("-e", "--endpoint", dest="endpoint", help=g_help("endpoint"), metavar="Endpoint",
                         default=default_endpoint)
    arg_man.add_argument("-f", "--filters", dest="filters", help=g_help("filters"), action="append", default=[])
    arg_man.add_argument("-p", "--print", dest="print_key", help=g_help("print_key"), nargs="*", metavar="key")
    arg_man.add_argument("--only-value", dest="only_value", help=g_help("only_value"), action="store_true",
                         default=False)
    arg_man.add_argument("-r", "--replace", dest="replace_file", help=g_help("replace_file"), metavar="file")
    if len(sys.argv) <= 1:
        sys.argv.append("-h")
    args = arg_man.parse_args()
    key_items = get_key(args.endpoint, args.app, args.filters)
    replace_file(args.replace_file, key_items)
    if args.print_key is not None:
        for p_key in args.print_key:
            if p_key in key_items:
                if args.only_value is True:
                    print(key_items[p_key])
                else:
                    print("%s\t%s" % (p_key, key_items[p_key]))
            else:
                error_and_exit(g_help("key_not_exist", p_key))

if __name__ == "__main__":
    sys.argv.extend(["-a", "mns", "-r", "mns.conf", "-p", "region", "access_id", "-f", "ljd=true", "--only-value"])
    handle_key()



#! /usr/bin/env python
# coding: utf-8

import sys
from functools import partial
from jingyun_cli.util.help import help_value

__author__ = '鹛桑够'


output_help = {"en": "the output of file, default is stdout.", "cn": "输出文件的路径，默认输出到标准输出流"}
json_file_help = {"en": "the path of json file", "cn": "json 文件的路径"}
file_not_exist_help = {"en": "file %s not exist", "cn": "文件%s不存在"}
read_error_help = {"en": "read file %s error", "cn": "读取文件%s失败"}
content_error_help = {"en": "file %s not json content", "cn": "文件%s里的内容不是json格式"}
cover_help = {"en": "whether or not to cover the input file. default is false. the priority is higher than arg -o or "
                    "--output", "cn": "是否覆盖输入文件。默认不覆盖。优先级高于参数-o和--output"}


help_keys = filter(lambda x: x.endswith("_help"), locals().keys())
help_dict = dict()
for key in help_keys:
    help_dict[key[:-5]] = locals()[key]


g_help = partial(help_value, help_dict)


def error_and_exit(msg, error_code=1):
    sys.stderr.write(msg)
    sys.stderr.write("\n")
    sys.exit(error_code)


#! /usr/bin/env python
# coding: utf-8

import sys
from functools import partial
from jingyun_cli import logger
from jingyun_cli.util.help import help_value

__author__ = '鹛桑够'

oss_dir_help = {"en": "", "cn": "ssh-key所在目录"}
endpoint_help = {"en": "oss server endpoint, for example http://jy-softs.oss-cn-beijing.aliyuncs.com",
                 "cn": "服务器端点,例如http://jy-softs.oss-cn-beijing.aliyuncs.com"}


help_keys = filter(lambda x: x.endswith("_help"), locals().keys())
help_dict = dict()
for key in help_keys:
    help_dict[key[:-5]] = locals()[key]

g_help = partial(help_value, help_dict)


def error_and_exit(msg, error_code=1):
    sys.stderr.write(msg)
    sys.stderr.write("\n")
    sys.exit(error_code)



#! /usr/bin/env python
# coding: utf-8

import sys
from functools import partial
from jingyun_cli.util.help import help_value

__author__ = '鹛桑够'

output_help = {"en": "the output of file, default is work dir.", "cn": "下载后的文件保存的目录，默认保存到当前工作目录"}
app_help = {"en": " what kind of application key belongs to, for example: mysql oss",
            "cn": "key属于哪类应用，例如mysql oss"}
print_key_help = {"en": "what information is included in the print key ", "cn": "打印密钥包含的哪些信息"}
only_value_help = {"en": "only print value", "cn": "只打印密钥要打印的密钥中的属性值，不打印属性"}
replace_file_help = {"en": "use key info format the file concent and rewrite",
                     "cn": "将该文件内容，使用密钥所包含的信息进行字符串格式化，再回写到该文件"}
endpoint_help = {"en": "dist key server endpoint, for example https://dms.gene.ac/dist/key/",
                 "cn": "密钥分发服务器端点,例如https://dms.gene.ac/dist/key/"}
filters_help = {"en": "other parameters used to filter keys. format is filter_key=filter_value",
                "cn": "其他用于筛选密钥的参数，格式为filter_key=filter_value"}

error_filter_help = {"en": "invalid filter string, please use filter_key=filter_value",
                     "cn": "无效的筛选字符串%s，请使用filter_key=filter_value"}
error_get_help = {"en": " unable to obtain a specified key, %s ", "cn": "无法获得指定的密钥,%s"}
file_not_exist_help = {"en": "file %s not exist", "cn": "文件%s不存在"}
key_not_exist_help = {"en": "key %s not exist", "cn": "密钥信息中不包含%s"}
read_error_help = {"en": "read file %s error", "cn": "读取文件%s失败"}
write_error_help = {"en": "rewrite file %s error", "cn": "重写文件%s失败"}

help_keys = filter(lambda x: x.endswith("_help"), locals().keys())
help_dict = dict()
for key in help_keys:
    help_dict[key[:-5]] = locals()[key]

g_help = partial(help_value, help_dict)


def error_and_exit(msg, error_code=1):
    sys.stderr.write(msg)
    sys.stderr.write("\n")
    sys.exit(error_code)



#! /usr/bin/env python
# coding: utf-8

import os
import subprocess

__author__ = '鹛桑够'


loaded_profile = set()


def source(filename):
    if os.path.exists(filename) is False:
        return
    abs_filename = os.path.abspath(filename)
    if abs_filename in loaded_profile:
        return
    cmd = "source %s && env" % filename
    output = subprocess.check_output(cmd, shell=True)
    lines = output.split("\n")
    for line in lines:
        if len(line) <= 0:
            continue
        key_value = line.split("=", 1)
        if len(key_value) != 2:
            continue
        key, value = key_value
        os.environ[key] = value


def source_local():
    home_dir = os.environ.get("HOME")
    local_profile = os.path.join(home_dir, ".bash_profile")
    source(local_profile)


def get_environ(key, failobj=None):
    source_local()
    return os.environ.get(key, failobj)


if __name__ == "__main__":
    MYSQL_ROOT_DIR = os.environ.get("MYSQL_ROOT_DIR")
    print(MYSQL_ROOT_DIR)
    source_local()
    MYSQL_ROOT_DIR = os.environ.get("MYSQL_ROOT_DIR")
    print(MYSQL_ROOT_DIR)


#! /usr/bin/env python
# coding: utf-8

import os
import sys
import argparse
from supervisor.supervisorctl import main as supervisorctl_main
from supervisor.supervisord import main as supervisord_main
from jingyun_cli import logger

try:
    from .help import g_help, error_and_exit
except ValueError:
    from help import g_help, error_and_exit

__author__ = '鹛桑够'





#! /usr/bin/env python
# coding: utf-8

import sys
from functools import partial
from jingyun_cli import logger
from jingyun_cli.util.help import help_value, error_and_exit

__author__ = '鹛桑够'

server_help = {"en": "", "cn": "使用服务预定义端口号列表"}
port_help = {"en": "", "cn": "要检测的端口号"}

help_keys = filter(lambda x: x.endswith("_help"), locals().keys())
help_dict = dict()
for key in help_keys:
    help_dict[key[:-5]] = locals()[key]

g_help = partial(help_value, help_dict)




#! /usr/bin/env python
# coding: utf-8

import os
import sys
import argparse
import requests
import datetime
import re
from jingyun_cli import logger

try:
    from .help import g_help, error_and_exit
except ValueError:
    from help import g_help, error_and_exit

__author__ = '鹛桑够'


arg_man = argparse.ArgumentParser()
default_endpoint = "http://jy-softs.oss-cn-beijing.aliyuncs.com"


def download_ssh_key(endpoint, oss_file, *oss_dir):
    endpoint = endpoint.rstrip("/")
    oss_dirs = map(lambda x: x.strip("/"), oss_dir)
    oss_dirs = filter(lambda x: x != "", oss_dirs)
    dir_path = "/".join(oss_dirs)
    if len(dir_path) > 0:
        url = "%s/%s/%s" % (endpoint, dir_path, oss_file)
    else:
        url = "%s/%s" % (endpoint, oss_file)
    resp = requests.get(url)
    return resp.status_code, resp.text


def write_file(save_dir, filename, content):
    save_path = os.path.join(save_dir, filename)
    if os.path.exists(save_path) is True:
        logger.debug("%s exist" % filename)
        with open(save_path, "r") as r:
            old_content = r.read()
            if old_content == content:
                logger.debug("%s old content is right" % filename)
                os.system("chmod 600 %s" % save_path)
                return save_path
            back_name = filename + ".jy" + datetime.datetime.now().strftime("%y%m%d%H%M") + ".bk"
            back_path = os.path.join(save_dir, back_name)
            logger.debug("backup old %s to %s" % (filename, back_name))
            with open(back_path, "w") as w:
                w.write(old_content)
    with open(save_path, "w") as w:
        w.write(content)
    os.system("chmod 600 %s" % save_path)
    return save_path


def write_authorized_keys(ssh_dir, content):
    save_path = os.path.join(ssh_dir, "authorized_keys")
    if os.path.exists(save_path) is True:
        with open(save_path, "r") as r:
            all_lines = r.readlines()
            if content in all_lines:
                os.system("chmod 600 %s" % save_path)
                return True
    with open(save_path, "a") as w:
        w.write(content)
    os.system("chmod 600 %s" % save_path)
    return True


def gen_key():
    cmd = ["ssh-keygen", "-C", "meisanggou", "-f", "id_rsa", "-N", "''"]


def non_key():
    arg_man.add_argument("-d", "--oss-dir", dest="oss_dir", help=g_help("oss_dir"), metavar="", default="ssh-key")
    arg_man.add_argument("-e", "--endpoint", dest="endpoint", help=g_help("endpoint"), metavar="",
                         default=default_endpoint)
    save_dir = os.path.join(os.environ.get("HOME"), ".ssh")
    os.system("mkdir -p %s" % save_dir)
    os.system("chmod 700 %s" % save_dir)
    jingd_env = os.environ.get("JINGD_ENV", "")

    args = arg_man.parse_args()
    code, content = download_ssh_key(args.endpoint, "id_rsa", args.oss_dir, jingd_env)
    code_pub, content_pub = download_ssh_key(args.endpoint, "id_rsa.pub", args.oss_dir, jingd_env)
    if code != 200 or code_pub != 200:
        if jingd_env == "":
            msg = "id_rsa: %s\nid_ras.pub: %s" % (code, code_pub)
            error_and_exit(msg)
        code, content = download_ssh_key(args.endpoint, "id_rsa", args.oss_dir)
        code_pub, content_pub = download_ssh_key(args.endpoint, "id_rsa.pub", args.oss_dir)
        if code != 200 or code_pub != 200:
            msg = "id_rsa: %s\nid_ras.pub: %s" % (code, code_pub)
            error_and_exit(msg)
    write_file(save_dir, "id_rsa", content)
    write_file(save_dir, "id_rsa.pub", content_pub)
    write_authorized_keys(save_dir, content_pub)


if __name__ == "__main__":

    non_key()



#! /usr/bin/env python
# coding: utf-8

import os
import sys
import argparse
import re
import ConfigParser
from jingyun_cli import logger
try:
    from .help import g_help, error_and_exit
except ValueError:
    from help import g_help, error_and_exit

__author__ = '鹛桑够'


arg_man = argparse.ArgumentParser()


def rewrite_conf(file_path, mode):
    if os.path.exists(file_path) is False:
        msg = g_help("file_not_exist", file_path)
        error_and_exit(msg)
    try:
        with open(file_path) as rf:
            c = rf.read()
    except IOError:
        error_and_exit(g_help("read_error", file_path))
        return
    if mode == 2:
        n_c = c % os.environ
    else:
        n_c = c.format(**os.environ)
    with open(file_path, "w") as w:
        w.write(n_c)


def read(conf_path, section, options, ignore=False):
    if os.path.exists(conf_path) is False:
        msg = g_help("file_not_exist", conf_path)
        if ignore is True:
            logger.warning(msg)
            return map(lambda x: "", options)
        error_and_exit(msg)
    config = ConfigParser.ConfigParser()
    config.read(conf_path)
    if config.has_section(section) is False:
        msg = g_help("section_not_found", section)
        if ignore is True:
            logger.warning(msg)
            return map(lambda x: "", options)
        error_and_exit(msg)
    values = []
    for option in options:
        if config.has_option(section, option) is False:
            msg = g_help("option_not_found", option)
            if ignore is True:
                logger.warning(msg)
                values.append("")
                continue
            error_and_exit(msg)
        values.append(config.get(section, option))
    return values


def list_files(directory, prefix, end, re_filter):
    files = os.listdir(directory)
    # 按照前缀筛选
    if prefix is not None:
        files = filter(lambda x: x.startswith(prefix), files)
    # 按照后缀筛选
    if end is not None:
        files = filter(lambda x: x.endswith(end), files)
    # 按照正则筛选
    if re_filter is not None:
        files = filter(lambda x: re.match(re_filter, x), files)

    # 获取全路径
    files = map(lambda x: os.path.join(directory, x), files)
    # 去除目录
    files = filter(lambda x: os.path.isfile(x), files)
    return files


def environ_format():
    arg_man.add_argument("-d", "--directory", dest="directory", help=g_help("directory"), metavar="directory")
    arg_man.add_argument("-p", "--prefix", dest="prefix", help=g_help("prefix"), metavar="prefix")
    arg_man.add_argument("-e", "--end", dest="end", help=g_help("end"), metavar="end")
    arg_man.add_argument("-f", "--filter", dest="filter", help=g_help("filter"), metavar="filter", default=r"\S*")
    arg_man.add_argument("-i", "-I", "--input", dest="input", help=g_help("conf_file"), metavar="conf_file",
                         action="append", default=[])
    arg_man.add_argument("inputs", metavar="conf_file", nargs="*", help=g_help("conf_file"))
    arg_man.add_argument("-m", "--mode", dest="mode", help=g_help("mode"), type=int, choices=[1, 2], default=1)

    if len(sys.argv) <= 1:
        sys.argv.append("-h")
    args = arg_man.parse_args()
    files = args.input
    files.extend(args.inputs)
    if args.directory is not None:
        files.extend(list_files(args.directory, args.prefix, args.end, args.filter))
    for item in files:
        logger.info("format %s" % item)
        rewrite_conf(item, args.mode)
        logger.info("format %s success\n" % item)


def read_conf():
    arg_man.add_argument("-c", "--conf-path", dest="conf_path", help=g_help("conf_file"), metavar="conf_path",
                         required=True)
    arg_man.add_argument("-i", "--ignore-error", dest="ignore_error", help=g_help("ignore_error"), action='store_true',
                         default=False)
    arg_man.add_argument("-s", "--section", dest="section", help=g_help("section"), metavar="section", required=True)
    arg_man.add_argument("option", metavar="option", nargs="*", help=g_help("option"))

    if len(sys.argv) <= 1:
        sys.argv.append("-h")

    args = arg_man.parse_args()

    values = read(args.conf_path, args.section, args.option, ignore=args.ignore_error)
    for v in values:
        print(v)

if __name__ == "__main__":
    sys.argv.extend(["-c", "/data/Web2/conf/mysql_app.conf", "-s", "db_basic", "port", "host2", "-i"])
    read_conf()



#! /usr/bin/env python
# coding: utf-8

import sys
from functools import partial
from jingyun_cli.util.help import help_value

__author__ = '鹛桑够'

conf_file_help = {"en": "the path of conf file", "cn": "配置文件的路径"}
file_not_exist_help = {"en": "file %s not exist", "cn": "文件%s不存在"}
read_error_help = {"en": "read file %s error", "cn": "读取文件%s失败"}
write_error_help = {"en": "rewrite file %s error", "cn": "重写文件%s失败"}
mode_help = {"en": "1 use str.format(os.environ),2 use str %% os.environ",
             "cn": "1代表使用str.format(os.environ)，2代表使用str %% os.environ"}
directory_help = {'en': '', 'cn': "遍历目录下所有文件，可与参数-p -e -f一起使用，筛选目录下文件"}
filter_help = {"en": "", "cn": "筛选条件，正则表达式，根据筛选条件进行match操作.-d存在时有效"}
prefix_help = {"en": "", "cn": "文件名开头，根据根据文件开头筛选目录中的文件.-d存在时有效"}
end_help = {"en": "", "cn": "文件名结尾，根据根据文件结尾筛选目录中的文件.-d存在时有效"}
section_help = {"en": "", "cn": "要查询的配置文件的哪部分"}
section_not_found_help = {"en": "", "cn": "要查询的配置文件%s部分不存在"}
option_help = {"en": "", "cn": "要查询的配置选项名"}
option_not_found_help = {"en": "", "cn": "要查询的配置选项%s不存在"}
ignore_error_help = {"end": "", "cn": "遇到错误如配置不存在，配置项不存在时，不报错仅打印信息"}


help_keys = filter(lambda x: x.endswith("_help"), locals().keys())
help_dict = dict()
for key in help_keys:
    help_dict[key[:-5]] = locals()[key]

g_help = partial(help_value, help_dict)


def error_and_exit(msg, error_code=1):
    sys.stderr.write(msg)
    sys.stderr.write("\n")
    sys.exit(error_code)



#! /usr/bin/env python
# coding: utf-8

#  __author__ = 'meisanggou'

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

import sys

if sys.version_info <= (2, 7):
    sys.stderr.write("ERROR: jingyun-cli requires Python Version 2.7 or above.\n")
    sys.stderr.write("Your Python Version is %s.%s.%s.\n" % sys.version_info[:3])
    sys.exit(1)

name = "jingyun-cli"
version = "0.5.6"
url = "https://github.com/meisanggou/jingyun"
license = "MIT"
author = "meisanggou"
short_description = "jingyun deploy cli tools"
long_description = """"""
keywords = "jingyun-cli"
install_requires = ["requests", "six", "supervisor", "docker-compose", "mysqldb-rich"]

entry_points = {'console_scripts': [
    'json-merge=jingyun_cli.json.cli:json_merge',
    'jy-json-merge=jingyun_cli.json.cli:json_merge',
    'jy-oss-download=jingyun_cli.oss.cli:multi_download',
    'jy-key=jingyun_cli.key.cli:handle_key',
    'jy-conf-format=jingyun_cli.conf.cli:environ_format',
    'jy-conf-read=jingyun_cli.conf.cli:read_conf',
    'jy-ssh-nonkey=jingyun_cli.ssh.cli:non_key',
    'jy-jingd-usermod=jingyun_cli.jingd.user:cli_main',
    'jy-jingd-reanalysis=jingyun_cli.jingd.sample:cli_main',
    'jy-supervisorctl=jingyun_cli.jingd.jy_supervisor:jy_supervisorctl',
    'jy-supervisord=jingyun_cli.jingd.jy_supervisor:jy_supervisord',
    'jy-docker-clear=jingyun_cli.docker.clear:clear',
    'jy-docker-compose=jingyun_cli.docker.jy_compose:main',
    'jy-sql-table=jingyun_cli.sql.cli:op_table',
    'jy-sql-link=jingyun_cli.sql.cli:link',
    'jy-server-port=jingyun_cli.server.find_port:find_one_port',
    'jy-server-ip=jingyun_cli.server.ip:get_ip'
]}

setup(name=name,
      version=version,
      author=author,
      author_email="zhouheng@gene.ac",
      url=url,
      packages=["jingyun_cli", "jingyun_cli/util", "jingyun_cli/json", "jingyun_cli/oss", "jingyun_cli/key",
                "jingyun_cli/conf", "jingyun_cli/ssh", "jingyun_cli/jingd", "jingyun_cli/docker", "jingyun_cli/sql",
                "jingyun_cli/server"],
      license=license,
      description=short_description,
      long_description=long_description,
      keywords=keywords,
      install_requires=install_requires,
      entry_points=entry_points
      )



#! /usr/bin/env python
# coding: utf-8

import os
import sys
from supervisor.supervisorctl import main as supervisorctl_main
from supervisor.supervisord import main as supervisord_main
from jingyun_cli.util.env import source_local
try:
    from .help import g_help, error_and_exit
except ValueError:
    from help import g_help, error_and_exit

__author__ = '鹛桑够'


def set_conf():
    source_local()
    conf_dir = os.environ.get("JINGD_CONF_DIR")
    if conf_dir is None:
        error_and_exit(g_help("defect_env", "JINGD_CONF_DIR"))
    conf_path = os.path.join(conf_dir, "supervisord.conf")
    if os.path.exists(conf_path) is False:
        error_and_exit(g_help("file_lost"))
    sys.argv.insert(1, "-c")
    sys.argv.insert(2, conf_path)


def jy_supervisorctl():
    set_conf()
    code = supervisorctl_main()
    sys.exit(code)


def jy_supervisord():
    set_conf()
    code = supervisord_main()
    sys.exit(code)


if __name__ == "__main__":
    import sys
    sys.argv.append("status")
    jy_supervisorctl()


#! /usr/bin/env python
# coding: utf-8

import os
import sys
import argparse
import json
try:
    from .help import g_help, error_and_exit
except ValueError:
    from help import g_help, error_and_exit

__author__ = '鹛桑够'


arg_man = argparse.ArgumentParser()


def add_output():
    arg_man.add_argument("-o", "--output", dest="output", help=g_help("output"), metavar="out")


def load_json(file_path):
    if os.path.exists(file_path) is False:
        msg = g_help("file_not_exist", file_path)
        error_and_exit(msg)
    try:
        with open(file_path) as rf:
            c = rf.read()
    except IOError:
        error_and_exit(g_help("read_error", file_path))
        return
    try:
        o = json.loads(c)
        return o
    except ValueError:
        error_and_exit(g_help("content_error", file_path))
        return


def json_output(o, file_path=None):
    o_s = json.dumps(o, indent=2)
    if file_path is not None:
        with open(file_path, "w") as wf:
            wf.write(o_s)
    else:
        print(o_s)


def json_merge():
    arg_man.add_argument("-i", "-I", "--input", dest="input", help=g_help("json_file"), action="append",
                         metavar="json_file", default=[])
    arg_man.add_argument("inputs", metavar="json_file", nargs="*", help=g_help("json_file"))
    add_output()
    if len(sys.argv) <= 1:
        sys.argv.append("-h")
    args = arg_man.parse_args()
    f_inputs = args.inputs
    f_inputs.extend(args.input)
    o = dict()
    for f in f_inputs:
        f_o = load_json(f)
        o.update(f_o)
    json_output(o, args.output)


def json_update():
    arg_man.add_argument("-c", "-C", dest="cover", help=g_help("cover"), action="store_true", default=False)
    arg_man.add_argument("-i", "-I", "--input", dest="input", help=g_help("json_file"), metavar="json_file")
    arg_man.add_argument("inputs", metavar="json_file", nargs="?", help=g_help("json_file"))
    add_output()
    if len(sys.argv) <= 1:
        sys.argv.append("-h")

    args = arg_man.parse_args()
    o = load_json(args.input)
    pass


def main():
    pass


if __name__ == "__main__":
    # sys.argv.append("a.json")
    # sys.argv.extend(["-i", "b.json"])
    # sys.argv.extend(["-o", "b.json"])

    json_update()


#! /usr/bin/env python
# coding: utf-8

import sys
import os
import argparse
try:
    from .help import g_help, error_and_exit, jy_input
except ValueError:
    from help import g_help, error_and_exit, jy_input
from jingyun_cli.jingd import request_jingd


def request_sample(method, url, data):
    return request_jingd("sample", method, url, data)


def req_process():
    url = "/sample/process/"
    r_data = request_sample("GET", url, None)
    all_process = r_data["data"]
    return all_process


def req_process_detail(process_no):
    url = "/sample/process/detail/"
    r_data = request_sample("POST", url, dict(process_no=process_no))
    params = r_data["data"]["params"]
    return params


def req_sample_info(sample_no):
    url = "/sample/info/"
    r_data = request_sample("GET", url, dict(sample_no=sample_no))
    seq_files = r_data["data"]["seq_files"]
    return seq_files


def req_sample_right(sample_no):
    url = "/sample/right/"
    r_data = request_sample("GET", url, dict(sample_no=sample_no))
    rights = r_data["data"]
    return rights


def req_analysis(account, sample_no, seq_files, bucket, process_no):
    url = "/sample/analysis/v2/"
    data = dict(sample_no=sample_no, seq_files=seq_files, bucket=bucket, process_no=process_no, account=account)
    print(data)
    confirm = jy_input("Confirm?").lower()
    if confirm in ["y", "yes"]:
        r_data = request_sample("POST", url, data)


def re_run(sample_no, account=None):
    seq_files = req_sample_info(sample_no)
    if seq_files is None:
        error_and_exit("Not Found seq_files")
    files = seq_files.split(",")
    if account is None:
        rights = req_sample_right(sample_no)
        for item in rights:
            if item["role"] == 0:
                account = item["account"]
    if account is None:
        error_and_exit("Auto Find Account Fail, Please Set Account")
    process_no = -1
    all_process = req_process()
    for p in all_process:
        if p["process_name"] == files[0]:
            process_no = p["process_no"]
    if process_no == -1:
        error_and_exit("Not Found Process Name Is %s" % files[0])
    params = req_process_detail(process_no)
    r_seq_files = dict()
    for p in params:
        r_seq_files[p["param_name"]] = ""
    keys = r_seq_files.keys()
    if len(keys) != len(files) - 1:
        print(keys)
        print(files)
        error_and_exit("Please Check input file")
    bucket = None
    for i in range(len(keys)):
        bucket, file_path = files[i + 1].split(":", 1)
        r_seq_files[keys[i]] = file_path
    req_analysis(account, sample_no, r_seq_files, bucket, process_no)


def cli_main():
    parser = argparse.ArgumentParser()
    parser.add_argument("-a", "--account", dest="account", help=g_help("user"))
    parser.add_argument("sample_no", help=g_help("sample_no"))
    if len(sys.argv) <= 1:
        sys.argv.append("-h")

    args = parser.parse_args()
    sample_no = int(args.sample_no)
    re_run(sample_no, args.account)


if __name__ == "__main__":
    sys.argv.extend(["205"])
    cli_main()
